# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contek_viper/execution/target_position.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,contek_viper/execution/target_position.proto\x12\x16\x63ontek_viper.execution\"h\n\x0eTargetPosition\x12\x0e\n\x06market\x18\x01 \x01(\t\x12\x13\n\x0bvalue_ratio\x18\x02 \x01(\x01\x12\x1d\n\x15\x61mplified_value_ratio\x18\x03 \x01(\x01\x12\x12\n\nmultiplier\x18\x04 \x01(\x01\x42\x1d\n\x19io.contek.viper.executionP\x01\x62\x06proto3')



_TARGETPOSITION = DESCRIPTOR.message_types_by_name['TargetPosition']
TargetPosition = _reflection.GeneratedProtocolMessageType('TargetPosition', (_message.Message,), {
  'DESCRIPTOR' : _TARGETPOSITION,
  '__module__' : 'contek_viper.execution.target_position_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.TargetPosition)
  })
_sym_db.RegisterMessage(TargetPosition)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.contek.viper.executionP\001'
  _TARGETPOSITION._serialized_start=72
  _TARGETPOSITION._serialized_end=176
# @@protoc_insertion_point(module_scope)
