# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contek_viper/execution/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from contek_viper.execution import target_position_pb2 as contek__viper_dot_execution_dot_target__position__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.contek_viper/execution/execution_service.proto\x12\x16\x63ontek_viper.execution\x1a,contek_viper/execution/target_position.proto\"\x82\x01\n\x1cSubmitTargetPositionsRequest\x12?\n\x0ftarget_position\x18\x01 \x03(\x0b\x32&.contek_viper.execution.TargetPosition\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\t\"\x1f\n\x1dSubmitTargetPositionsResponse2\x9b\x01\n\x10\x45xecutionService\x12\x86\x01\n\x15SubmitTargetPositions\x12\x34.contek_viper.execution.SubmitTargetPositionsRequest\x1a\x35.contek_viper.execution.SubmitTargetPositionsResponse\"\x00\x42\x1d\n\x19io.contek.viper.executionP\x01\x62\x06proto3')



_SUBMITTARGETPOSITIONSREQUEST = DESCRIPTOR.message_types_by_name['SubmitTargetPositionsRequest']
_SUBMITTARGETPOSITIONSRESPONSE = DESCRIPTOR.message_types_by_name['SubmitTargetPositionsResponse']
SubmitTargetPositionsRequest = _reflection.GeneratedProtocolMessageType('SubmitTargetPositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTARGETPOSITIONSREQUEST,
  '__module__' : 'contek_viper.execution.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.SubmitTargetPositionsRequest)
  })
_sym_db.RegisterMessage(SubmitTargetPositionsRequest)

SubmitTargetPositionsResponse = _reflection.GeneratedProtocolMessageType('SubmitTargetPositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTARGETPOSITIONSRESPONSE,
  '__module__' : 'contek_viper.execution.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.SubmitTargetPositionsResponse)
  })
_sym_db.RegisterMessage(SubmitTargetPositionsResponse)

_EXECUTIONSERVICE = DESCRIPTOR.services_by_name['ExecutionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.contek.viper.executionP\001'
  _SUBMITTARGETPOSITIONSREQUEST._serialized_start=121
  _SUBMITTARGETPOSITIONSREQUEST._serialized_end=251
  _SUBMITTARGETPOSITIONSRESPONSE._serialized_start=253
  _SUBMITTARGETPOSITIONSRESPONSE._serialized_end=284
  _EXECUTIONSERVICE._serialized_start=287
  _EXECUTIONSERVICE._serialized_end=442
# @@protoc_insertion_point(module_scope)
